@@ -392,6 +392,22 @@ impl DataBuffer {
         &mut *ptr.offset(i as isize)
     }
 
+    /// Get a `const` reference to the byte slice of the `i`'th element of the buffer.
+    #[inline]
+    pub fn get_bytes(&self, i: usize) -> &[u8] {
+        assert!(i < self.len());
+        let element_size = self.element_size();
+        &self.data[i*element_size..(i+1)*element_size]
+    }
+
+    /// Get a mutable reference to the byte slice of the `i`'th element of the buffer.
+    #[inline]
+    pub fn get_bytes_mut(&mut self, i: usize) -> &mut [u8] {
+        assert!(i < self.len());
+        let element_size = self.element_size();
+        &mut self.data[i*element_size..(i+1)*element_size]
+    }
+
     /// Move buffer data to a vector with a given type, reinterpreting the data type as
     /// required.
     #[inline]
@@ -901,6 +917,12 @@ mod tests {
             assert_eq!(val, vec_f32[i]);
         }
 
+        // Test byte getters
+        for i in 5..7 {
+            assert_eq!(buf.get_bytes(i), &[0,0,0,0]);
+            assert_eq!(buf.get_bytes_mut(i), &[0,0,0,0]);
+        }
+
         vec_f32.push(0.0);
         buf.push_bytes(&[0,0,0,0]).unwrap();
 
@@ -912,8 +934,9 @@ mod tests {
     /// Test appending to a data buffer from other slices and vectors.
     #[test]
     fn extend_append_test() {
-        let mut buf = DataBuffer::with_type::<f32>(); // Convert into buffer
+        let mut buf = DataBuffer::with_type::<f32>(); // Create an empty buffer.
 
+        // Append an ordianry vector of data.
         let vec_f32 = vec![1.0_f32, 23.0, 0.01, 42.0, 11.43];
         let mut vec_bytes: Vec<u8> = reinterpret::reinterpret_vec(vec_f32.clone());
         buf.append_bytes(&mut vec_bytes);
@@ -924,6 +947,15 @@ mod tests {
 
         buf.clear();
         assert_eq!(buf.len(), 0);
+
+        // Append a temporary vec.
+        buf.append_bytes(&mut vec![0u8; 4]);
+        assert_eq!(buf.get::<f32>(0).unwrap(), 0.0f32);
+
+        buf.clear();
+        assert_eq!(buf.len(), 0);
+
+        // Extend buffer with a slice
         let slice_bytes: &[u8] = reinterpret::reinterpret_slice(&vec_f32);
         buf.extend_bytes(slice_bytes);
 
